Audit Proof Certificate - export-demo-001

InALign
Audit Trail Proof Certificate
Certificate Information
Certificate ID: cert-f693bbede088
Issued: 2026-02-05T09:24:04.290576+00:00
Session ID: export-demo-001
Audit Trail Summary
Total Records: 3
First Activity: 2026-02-05T09:24:04.290576+00:00
Last Activity: 2026-02-05T09:24:04.290576+00:00
Chain Integrity: ✓ VERIFIED
Cryptographic Proof
Merkle Root: 36ddea2016602db3b449ae1118e6d336a448b14811f22a62b342008125be50a5
Status: Pending blockchain anchor